@@ -1,7 +1,7 @@
 /*
  * Mailbox folder access
  *
- * Copyright (C) 2004--2008  Enrico Zini <enrico@debian.org>
+ * Copyright (C) 2013  Enrico Zini <enrico@debian.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -18,8 +18,10 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
  */
 
+#include "config.h"
 #include <buffy/utils/system.h>
 #include <tests/test-utils.h>
+#include <sys/stat.h>
 
 namespace tut {
 using namespace buffy;
@@ -33,10 +35,12 @@ struct buffy_utils_system_shar {
 };
 TESTGRP(buffy_utils_system);
 
-// TODO
+// Make sure that we are built with largefile support, so that we agree with
+// libwibble
 template<> template<>
 void to::test<1>()
 {
+    wassert(actual(sizeof(off_t)) == 8);
 }
 
 }
