@@ -17,18 +17,6 @@
  */
 
 #include <buffy/utils/system.h>
-#include <wibble/exception.h>
-
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <unistd.h>
-#include <dirent.h>
-#include <errno.h>
-#include <cstdio>
-
-
-using namespace std;
-using namespace wibble;
 
 namespace buffy
 {
